@@ -1,7 +1,7 @@
 package Bencher::Formatter::AddVsSlowestField;
 
-our $DATE = '2016-05-20'; # DATE
-our $VERSION = '1.008'; # VERSION
+our $DATE = '2016-06-17'; # DATE
+our $VERSION = '1.009'; # VERSION
 
 use 5.010001;
 use strict;
@@ -28,7 +28,7 @@ sub munge_result {
     $self->add_field(
         $envres,
         'vs_slowest',
-        {after=>'time'},
+        {after=>'time', align=>'number'},
         sub {
             for my $rit (@{$envres->[2]}) {
                 $rit->{vs_slowest} = $slowest_time / $rit->{time};
@@ -52,7 +52,7 @@ Bencher::Formatter::AddVsSlowestField - Add vs_slowest field
 
 =head1 VERSION
 
-This document describes version 1.008 of Bencher::Formatter::AddVsSlowestField (from Perl distribution Bencher-Backend), released on 2016-05-20.
+This document describes version 1.009 of Bencher::Formatter::AddVsSlowestField (from Perl distribution Bencher-Backend), released on 2016-06-17.
 
 =head1 DESCRIPTION
 
