@@ -1,7 +1,7 @@
 package Bencher::Role::FieldMunger;
 
-our $DATE = '2016-05-20'; # DATE
-our $VERSION = '1.008'; # VERSION
+our $DATE = '2016-06-17'; # DATE
+our $VERSION = '1.009'; # VERSION
 
 use 5.010;
 use strict;
@@ -16,6 +16,7 @@ sub add_field {
 
     my $ff = $envres->[3]{'table.fields'};
     my $fu = $envres->[3]{'table.field_units'};
+    my $fa = $envres->[3]{'table.field_aligns'};
 
     my $pos = 0;
     for my $i (0..$#{$ff}) {
@@ -44,6 +45,13 @@ sub add_field {
         }
         splice @$fu, $pos, 0, $unit;
     }
+    if ($fa) {
+        my $align;
+        if ($opts->{align}) {
+            $align = $opts->{align};
+        }
+        splice @$fa, $pos, 0, $align;
+    }
 }
 
 sub delete_fields {
@@ -57,11 +65,13 @@ sub delete_fields {
 
     my $ff = $envres->[3]{'table.fields'};
     my $fu = $envres->[3]{'table.field_units'};
+    my $fa = $envres->[3]{'table.field_aligns'};
 
     for my $i (reverse 0..$#{$ff}) {
         if (grep {$ff->[$i] eq $_} @names) {
             splice @$ff, $i, 1;
             splice @$fu, $i, 1 if $fu && @$fu > $i;
+            splice @$fa, $i, 1 if $fa && @$fa > $i;
         }
     }
 }
@@ -81,7 +91,7 @@ Bencher::Role::FieldMunger - Field munger role
 
 =head1 VERSION
 
-This document describes version 1.008 of Bencher::Role::FieldMunger (from Perl distribution Bencher-Backend), released on 2016-05-20.
+This document describes version 1.009 of Bencher::Role::FieldMunger (from Perl distribution Bencher-Backend), released on 2016-06-17.
 
 =for Pod::Coverage .*
 
